@@ -7,7 +7,7 @@ require Exporter;
 *import = \&Exporter::import;
 @EXPORT_OK=qw(dump pp);
 
-$VERSION = "1.05";  # $Date: 2004/11/11 10:02:31 $
+$VERSION = "1.07";  # $Date: 2006/11/24 16:23:06 $
 $DEBUG = 0;
 
 use overload ();
@@ -231,7 +231,7 @@ sub _dump
     }
     elsif ($type eq "ARRAY") {
 	my @vals;
-	my $tied = tied_str(tied(%$rval));
+	my $tied = tied_str(tied(@$rval));
 	my $i = 0;
 	for my $v (@$rval) {
 	    push(@vals, _dump($v, $name, [@$idx, "[$i]"], $tied));
@@ -415,24 +415,13 @@ sub quote {
   s/([\\\"\@\$])/\\$1/g;
   return qq("$_") unless /[^\040-\176]/;  # fast exit
 
-  my $high = $_[1];
   s/([\a\b\t\n\f\r\e])/$esc{$1}/g;
 
   # no need for 3 digits in escape for these
   s/([\0-\037])(?!\d)/sprintf('\\%o',ord($1))/eg;
 
-  if ($high) {
-      s/([\0-\037\177])/sprintf('\\%03o',ord($1))/eg;
-      if ($high eq "iso8859") {
-          s/[\200-\240]/sprintf('\\%o',ord($1))/eg;
-      } elsif ($high eq "utf8") {
-#         use utf8;
-#         $str =~ s/([^\040-\176])/sprintf "\\x{%04x}", ord($1)/ge;
-      }
-  } else {
-      s/([\0-\037\177-\377])/sprintf('\\x%02X',ord($1))/eg;
-      s/([^\040-\176])/sprintf('\\x{%X}',ord($1))/eg;
-  }
+  s/([\0-\037\177-\377])/sprintf('\\x%02X',ord($1))/eg;
+  s/([^\040-\176])/sprintf('\\x{%X}',ord($1))/eg;
 
   if (length($_) > 40  && !/\\x\{/ && length($_) > (length($_[0]) * 2)) {
       # too much binary data, better to represent as a hex/base64 string
